package org.cynetec.lib.system;

import java.nio.ByteBuffer;

public final class ByteBufferUtils {

	/**
	 * puts a string into the byte buffer (binary)
	 * 
	 * @param buffer
	 * @param string
	 */
	static public void putString(ByteBuffer buffer, String string) {
		for (int i = 0; i < string.length(); i++)
			putChar(buffer, string.charAt(i));
	}

	/**
	 * puts a char into the byte buffer (binary)
	 * 
	 * @param buffer
	 * @param character
	 */
	static public void putChar(ByteBuffer buffer, char character) {
		buffer.put((byte) (character & 0xFF));
	}

	/**
	 * gets a string from the byte buffer (binary)
	 * 
	 * @param buffer
	 *            the buffer to read from
	 * @param size
	 *            the strings length
	 * @return the string
	 */
	static public String getString(ByteBuffer buffer, int size) {
		byte[] b = new byte[size];
		char[] c = new char[size];
		buffer.get(b);
		for (int i = 0; i < size; i++)
			c[i] = (char) ((b[i] & 0x7F) + (b[i] < 0 ? 128 : 0));
		return new String(c);
	}

	/**
	 * gets a char from the byte buffer (binary)
	 * 
	 * @param buffer
	 *            the buffer to read from
	 * @return the char
	 */
	static public char getChar(ByteBuffer buffer) {
		byte b = buffer.get();
		return (char) ((b & 0x7F) + (b < 0 ? 128 : 0));
	}

}